************
Installation
************

You can install the stable version of `tynt` from PyPI with::

    pip install tynt

Alternatively, you can install the latest developer version of astroplan by
cloning the git repository::

    git clone https://github.com/bmorris3/tynt

...then installing the package with::

    cd tynt
    pip install -e .[all]
